@@ -5,10 +5,10 @@ from subprocess import Popen,PIPE
 from crystals import Crystal,Lattice
 from utils import handler3D as h3D          #;imp.reload(h3D)
 from utils import displayStandards as dsp   #;imp.reload(dsp)
-from multislice  import mupy_utils as mut   #;imp.reload(mut)
+# from multislice  import mupy_utils as mut   #;imp.reload(mut)
 from EDutils import viewers as vw           ;imp.reload(vw)
 from EDutils import utilities as ut         #;imp.reload(ut)
-from multislice.rotating_crystal import get_crystal_rotation
+# from multislice.rotating_crystal import get_crystal_rotation
 
 class Pets:
     def __init__(self,pts_file:str,
